@@ -1,8 +1,11 @@
 # Copyright Contributors to the Amundsen project.
 # SPDX-License-Identifier: Apache-2.0
 
+from typing import (  # noqa: F401
+    Any, Dict, Iterator, Union,
+)
+
 from pyhocon import ConfigFactory, ConfigTree  # noqa: F401
-from typing import Iterator, Union, Dict, Any  # noqa: F401
 
 from databuilder.extractor.base_postgres_metadata_extractor import BasePostgresMetadataExtractor
 
@@ -12,12 +15,11 @@ class PostgresMetadataExtractor(BasePostgresMetadataExtractor):
     Extracts Postgres table and column metadata from underlying meta store database using SQLAlchemyExtractor
     """
 
-    def get_sql_statement(self, use_catalog_as_cluster_name, where_clause_suffix):
-        # type: (bool, str) -> str
+    def get_sql_statement(self, use_catalog_as_cluster_name: bool, where_clause_suffix: str) -> str:
         if use_catalog_as_cluster_name:
             cluster_source = "c.table_catalog"
         else:
-            cluster_source = "'{}'".format(self._cluster)
+            cluster_source = f"'{self._cluster}'"
 
         return """
         SELECT
@@ -38,6 +40,5 @@ class PostgresMetadataExtractor(BasePostgresMetadataExtractor):
             where_clause_suffix=where_clause_suffix,
         )
 
-    def get_scope(self):
-        # type: () -> str
+    def get_scope(self) -> str:
         return 'extractor.postgres_metadata'
